/// <reference types="node" />
import { Injector } from '@angular/core';
import { BaseSession } from 'tabby-terminal';
import { Client, ClientChannel, SFTPWrapper } from 'ssh2';
import { Observable } from 'rxjs';
import { ProxyCommandStream } from '../services/ssh.service';
import { SFTPSession } from './sftp';
import { SSHProfile } from '../api';
import { ForwardedPort } from './forwards';
export declare class KeyboardInteractivePrompt {
    name: string;
    instruction: string;
    prompts: string[];
    private callback;
    responses: string[];
    constructor(name: string, instruction: string, prompts: string[], callback: (_: string[]) => void);
    respond(): void;
}
export declare class SSHSession extends BaseSession {
    private injector;
    profile: SSHProfile;
    shell?: ClientChannel;
    ssh: Client;
    sftp?: SFTPWrapper;
    forwardedPorts: ForwardedPort[];
    jumpStream: any;
    proxyCommandStream: ProxyCommandStream | null;
    savedPassword?: string;
    get serviceMessage$(): Observable<string>;
    get keyboardInteractivePrompt$(): Observable<KeyboardInteractivePrompt>;
    agentPath?: string;
    activePrivateKey: string | null;
    private remainingAuthMethods;
    private serviceMessage;
    private keyboardInteractivePrompt;
    private keychainPasswordUsed;
    private authUsername;
    private passwordStorage;
    private ngbModal;
    private hostApp;
    private platform;
    private notifications;
    private zone;
    private fileProviders;
    private config;
    constructor(injector: Injector, profile: SSHProfile);
    init(): Promise<void>;
    openSFTP(): Promise<SFTPSession>;
    start(interactive?: boolean): Promise<void>;
    emitServiceMessage(msg: string): void;
    emitKeyboardInteractivePrompt(prompt: KeyboardInteractivePrompt): void;
    handleAuth(methodsLeft?: string[] | null): Promise<any>;
    addPortForward(fw: ForwardedPort): Promise<void>;
    removePortForward(fw: ForwardedPort): Promise<void>;
    resize(columns: number, rows: number): void;
    write(data: Buffer): void;
    kill(signal?: string): void;
    destroy(): Promise<void>;
    getChildProcesses(): Promise<any[]>;
    gracefullyKillProcess(): Promise<void>;
    supportsWorkingDirectory(): boolean;
    getWorkingDirectory(): Promise<string | null>;
    private openShellChannel;
    loadPrivateKey(privateKeyContents?: Buffer): Promise<string | null>;
    parsePrivateKey(privateKey: string): Promise<any>;
}
